# -*- coding: utf-8 -*-
"""Setup tests for this package."""
from retrans.poi.testing import RETRANS_POI_INTEGRATION_TESTING  # noqa
from plone import api

import unittest


class TestSetup(unittest.TestCase):
    """Test that retrans.poi is properly installed."""

    layer = RETRANS_POI_INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer['portal']
        self.installer = api.portal.get_tool('portal_quickinstaller')

    def test_product_installed(self):
        """Test if retrans.poi is installed."""
        self.assertTrue(self.installer.isProductInstalled(
            'retrans.poi'))

    def test_browserlayer(self):
        """Test that IRetransPoiLayer is registered."""
        from retrans.poi.interfaces import (
            IRetransPoiLayer)
        from plone.browserlayer import utils
        self.assertIn(IRetransPoiLayer, utils.registered_layers())


class TestUninstall(unittest.TestCase):

    layer = RETRANS_POI_INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer['portal']
        self.installer = api.portal.get_tool('portal_quickinstaller')
        self.installer.uninstallProducts(['retrans.poi'])

    def test_product_uninstalled(self):
        """Test if retrans.poi is cleanly uninstalled."""
        self.assertFalse(self.installer.isProductInstalled(
            'retrans.poi'))

    def test_browserlayer_removed(self):
        """Test that IRetransPoiLayer is removed."""
        from retrans.poi.interfaces import IRetransPoiLayer
        from plone.browserlayer import utils
        self.assertNotIn(IRetransPoiLayer, utils.registered_layers())
